pub enum CharsetEncodeErrorKind {
InvalidCodePoint {
value: u32,
},
InvalidInputIndex {
input_len: usize,
},
InvalidOutputIndex {
output_len: usize,
},
UnmappableCharacter {
value: u32,
},
BufferTooSmall {
required: usize,
available: usize,
},
}Expand description
Classifies failures detected while encoding Unicode text into encoded units.
Variants
InvalidCodePoint
The supplied code point is not a valid Unicode scalar value.
InvalidInputIndex
The requested input character index is outside the input buffer.
InvalidOutputIndex
The requested output unit index is outside the output buffer.
UnmappableCharacter
The character cannot be represented by the target encoding.
BufferTooSmall
The supplied output buffer is too small for the encoded character.
Implementations
Sourceimpl CharsetEncodeErrorKind
impl CharsetEncodeErrorKind
Sourcepub const fn value(self) -> Option<u32>
pub const fn value(self) -> Option<u32>
Returns the raw value associated with the error kind, if available.
Returns
Some(value)forSelf::InvalidCodePointandSelf::UnmappableCharacter;Nonefor other kinds.
Sourcepub const fn required(self) -> Option<usize>
pub const fn required(self) -> Option<usize>
Returns the number of required output units for this kind, if available.
Returns
Some(required)forSelf::BufferTooSmall;Nonefor all other variants.
Sourcepub const fn available(self) -> Option<usize>
pub const fn available(self) -> Option<usize>
Returns the number of currently available output units for this kind, if available.
Returns
Some(available)forSelf::BufferTooSmall;Nonefor all other variants.
Sourcepub const fn input_len(self) -> Option<usize>
pub const fn input_len(self) -> Option<usize>
Returns the input length when this error comes from an invalid input index.
Returns
Some(input_len)forSelf::InvalidInputIndex;Nonefor other variants.
Sourcepub const fn output_len(self) -> Option<usize>
pub const fn output_len(self) -> Option<usize>
Returns the output length when this error comes from an invalid output index.
Returns
Some(output_len)forSelf::InvalidOutputIndex;Nonefor other variants.