pub struct CharsetDecodePolicy { /* private fields */ }Expand description
Malformed-input policy used by charset decoders and converters.
Implementations
Sourceimpl CharsetDecodePolicy
impl CharsetDecodePolicy
Sourcepub const DEFAULT_REPLACEMENT: char = '\u{fffd}'
pub const DEFAULT_REPLACEMENT: char = '\u{fffd}'
Default replacement character used when malformed input is replaced.
Sourcepub const fn new(malformed_action: MalformedAction, replacement: char) -> Self
pub const fn new(malformed_action: MalformedAction, replacement: char) -> Self
Creates a malformed-input policy.
Sourcepub const fn ignore() -> Self
pub const fn ignore() -> Self
Creates an ignore policy with the default replacement retained for metadata.
Sourcepub const fn ignore_with_replacement(replacement: char) -> Self
pub const fn ignore_with_replacement(replacement: char) -> Self
Creates an ignore policy with explicit replacement metadata.
Sourcepub const fn report() -> Self
pub const fn report() -> Self
Creates a report policy with the default replacement retained for metadata.
Sourcepub const fn malformed_action(self) -> MalformedAction
pub const fn malformed_action(self) -> MalformedAction
Returns the malformed-input action.
Sourcepub const fn replacement(self) -> char
pub const fn replacement(self) -> char
Returns the replacement character.