pub struct Utf16ByteCodec { /* private fields */ }Expand description
Combined byte-serialized UTF-16 codec.
The codec uses one configured byte order for both decoding and encoding. It
does not detect, consume, or emit a BOM automatically; callers should use
crate::UnicodeBom when a byte stream may carry an explicit BOM.
Examples
use qubit_codec_text::{
ByteOrder,
CharsetCodec,
CharsetEncodeProbe,
Codec,
Charset,
Utf16,
Utf16ByteCodec,
};
let codec = Utf16ByteCodec::new(ByteOrder::LittleEndian);
assert_eq!(Charset::UTF_16LE, codec.charset());
assert_eq!(Utf16::MAX_BYTES_PER_CHAR, codec.max_units_per_value().get());
let mut output = [0_u8; Utf16::MAX_BYTES_PER_CHAR];
let written = codec.encode_len('😀', 0).expect("mappable");
unsafe {
codec.encode_unchecked(&'😀', &mut output, 0).expect("buffer fits");
}
let (value, consumed) = unsafe {
codec.decode_unchecked(&output[..written], 0).expect("valid UTF-16LE")
};
assert_eq!(('😀', written), (value, consumed.get()));Implementations
Sourceimpl Utf16ByteCodec
impl Utf16ByteCodec
Sourcepub const fn byte_order(self) -> ByteOrder
pub const fn byte_order(self) -> ByteOrder
Sourcepub const fn charset(self) -> Charset
pub const fn charset(self) -> Charset
Returns the fixed-endian UTF-16 charset descriptor.
Returns
Returns Charset::UTF_16LE or Charset::UTF_16BE according to this
codec’s configured byte order.