pub struct Utf32ByteCodec { /* private fields */ }Expand description
Combined byte-serialized UTF-32 codec.
The codec uses one configured byte order for both decoding and encoding. It
does not detect, consume, or emit a BOM automatically; callers should use
crate::UnicodeBom when a byte stream may carry an explicit BOM.
Examples
use qubit_codec_text::{
ByteOrder,
CharsetCodec,
CharsetEncodeProbe,
Codec,
Charset,
Utf32,
Utf32ByteCodec,
};
let codec = Utf32ByteCodec::new(ByteOrder::BigEndian);
assert_eq!(Charset::UTF_32BE, codec.charset());
assert_eq!(Utf32::MAX_BYTES_PER_CHAR, codec.max_units_per_value().get());
let mut output = [0_u8; Utf32::MAX_BYTES_PER_CHAR];
let written = codec.encode_len('中', 0).expect("mappable");
unsafe {
codec.encode_unchecked(&'中', &mut output, 0).expect("buffer fits");
}
let (value, consumed) = unsafe {
codec.decode_unchecked(&output[..written], 0).expect("valid UTF-32BE")
};
assert_eq!(('中', written), (value, consumed.get()));Implementations
Sourceimpl Utf32ByteCodec
impl Utf32ByteCodec
Sourcepub const fn byte_order(self) -> ByteOrder
pub const fn byte_order(self) -> ByteOrder
Sourcepub const fn charset(self) -> Charset
pub const fn charset(self) -> Charset
Returns the fixed-endian UTF-32 charset descriptor.
Returns
Returns Charset::UTF_32LE or Charset::UTF_32BE according to this
codec’s configured byte order.